@@ -436,6 +436,14 @@ describe WebMock::RequestPattern do
           end
         end
       end
+
+      describe "when uri is passed as Pathname" do
+        it "should raise an ArgumentError" do
+          expect {
+            WebMock::RequestPattern.new(:get, Pathname.new("www.example.com"))
+          }.to raise_error(ArgumentError, "URI should be a String, Regexp, Addressable::Template or a callable object. Got: Pathname")
+        end
+      end
     end
 
     describe "when matching requests with body" do
@@ -562,7 +570,7 @@ describe WebMock::RequestPattern do
             it "should not match when body is not json" do
               expect(WebMock::RequestPattern.new(:post, 'www.example.com', body: body_hash)).
                 not_to match(WebMock::RequestSignature.new(:post, "www.example.com",
-                                                               headers: {content_type: content_type}, body: "foo bar"))
+                                                               headers: {content_type: content_type}, body: "[foo bar"))
             end
 
             it "should not match if request body is different" do
@@ -614,7 +622,7 @@ describe WebMock::RequestPattern do
             it "should not match when body is not xml" do
               expect(WebMock::RequestPattern.new(:post, 'www.example.com', body: body_hash)).
                 not_to match(WebMock::RequestSignature.new(:post, "www.example.com",
-                                                               headers: {content_type: content_type}, body: "foo bar"))
+                                                               headers: {content_type: content_type}, body: "<foo bar"))
                 end
 
             it "matches when the content type include a charset" do
